@@ -2,10 +2,10 @@
  * @package      hubzero-textifier
  * @file         textifier.cpp
  * @author       Steve Snyder <snyder13@purdue.edu>
- * @copyright    Copyright (c) 2012 HUBzero Foundation, LLC.
+ * @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
  * @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright (c) 2012 HUBzero Foundation, LLC.
+ * Copyright (c) 2012-2013 HUBzero Foundation, LLC.
  *
  * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
@@ -35,8 +35,13 @@
 #include "poppler/TextOutputDev.h"
 #include "poppler/GlobalParams.h"
 
+#ifdef RHCOMPILE
+#include "cryptopp/sha.h"
+#include "cryptopp/hex.h"
+#else
 #include "crypto++/sha.h"
 #include "crypto++/hex.h"
+#endif
 
 #include "mysql++/mysql++.h"
 
